#!/usr/bin/python
# -*- coding: koi8-r -*-
from distutils.core import setup,sys
import os

if sys.version < '2.2.3':
    from distutils.dist import DistributionMetadata
    DistributionMetadata.classifiers = None
    DistributionMetadata.download_url = None

# Set proper release version in source code also!!!
setup(name='ltsp',
      version='0.1',
      author='Oliver Grawert',
      author_email='ogra@ubuntu.com',
      url='http://launchpad.net/python-ltsp/',
      description='functions to access ltsp servers',
      long_description="""This library provides functionality for writing ltsp 
admin interfaces.

It is distributed under the terms of GPL.""",
      download_url='http://launchpad.net/python-ltsp/',
      packages=['ltsp'],
      license="GPL",
      platforms="All",
      keywords=['ltsp','thinclient'],
      classifiers = [
          'Topic :: System :: Systems Administration',
          'License :: OSI Approved :: GNU General Public License (GPL)',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Natural Language :: English',
          'Development Status :: 1 - Alpha',
          'Intended Audience :: Developers',
        ],
     )
